==> x_ite-4.7.15.jar: META-INF/resources/webjars/x_ite/4.7.15/src/x_ite/Components/Core/X3DChildNode.js <==
/* -*- Mode: JavaScript; coding: utf-8; tab-width: 3; indent-tabs-mode: tab; c-basic-offset: 3 -*-
 *******************************************************************************
 *
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * Copyright create3000, Scheffelstraße 31a, Leipzig, Germany 2011.
 *
 * All rights reserved. Holger Seelig <holger.seelig@yahoo.de>.
 *
 * The copyright notice above does not evidence any actual of intended
 * publication of such source code, and is an unpublished work by create3000.
 * This material contains CONFIDENTIAL INFORMATION that is the property of
 * create3000.
 *
 * No permission is granted to copy, distribute, or create derivative works from
 * the contents of this software, in whole or in part, without the prior written
 * permission of create3000.
 *
 * NON-MILITARY USE ONLY
 *
 * All create3000 software are effectively free software with a non-military use
 * restriction. It is free. Well commented source is provided. You may reuse the
 * source in any way you please with the exception anything that uses it must be
 * marked to indicate is contains 'non-military use only' components.
 *
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * Copyright 2015, 2016 Holger Seelig <holger.seelig@yahoo.de>.
 *
 * This file is part of the X_ITE Project.
 *
 * X_ITE is free software: you can redistribute it and/or modify it under the
 * terms of the GNU General Public License version 3 only, as published by the
 * Free Software Foundation.
 *
 * X_ITE is distributed in the hope that it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
 * A PARTICULAR PURPOSE. See the GNU General Public License version 3 for more
 * details (a copy is included in the LICENSE file that accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version 3
 * along with X_ITE.  If not, see <http://www.gnu.org/licenses/gpl.html> for a
 * copy of the GPLv3 License.
 *
 * For Silvio, Joy and Adi.
 *
 ******************************************************************************/


define ([
	"x_ite/Fields",
	"x_ite/Components/Core/X3DNode",
	"x_ite/Bits/X3DConstants",
],
function (Fields,
          X3DNode, 
          X3DConstants)
{
"use strict";

	function X3DChildNode (executionContext)
	{
		if (this .getExecutionContext ())
			return;

		X3DNode .call (this, executionContext);

		this .addType (X3DConstants .X3DChildNode);

		this .addChildObjects ("isCameraObject",   new Fields .SFBool ());
		this .addChildObjects ("isPickableObject", new Fields .SFBool ());

		this .isCameraObject_   .setAccessType (X3DConstants .outputOnly);
		this .isPickableObject_ .setAccessType (X3DConstants .outputOnly);
	}

	X3DChildNode .prototype = Object .assign (Object .create (X3DNode .prototype),
	{
		constructor: X3DChildNode,
		setCameraObject: function (value)
		{
			if (value !== this .isCameraObject_ .getValue ())
				this .isCameraObject_ = value;
		},
		getCameraObject: function ()
		{
			return this .isCameraObject_ .getValue ();
		},
		setPickableObject: function (value)
		{
			if (value !== this .isPickableObject_ .getValue ())
				this .isPickableObject_ = value;
		},
		getPickableObject: function ()
		{
			return this .isPickableObject_ .getValue ();
		},
	});

	return X3DChildNode;
});

==> x_ite-5.0.0.jar: META-INF/resources/webjars/x_ite/5.0.0/src/x_ite/Components/Core/X3DChildNode.js <==
/* -*- Mode: JavaScript; coding: utf-8; tab-width: 3; indent-tabs-mode: tab; c-basic-offset: 3 -*-
 *******************************************************************************
 *
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * Copyright create3000, Scheffelstraße 31a, Leipzig, Germany 2011.
 *
 * All rights reserved. Holger Seelig <holger.seelig@yahoo.de>.
 *
 * The copyright notice above does not evidence any actual of intended
 * publication of such source code, and is an unpublished work by create3000.
 * This material contains CONFIDENTIAL INFORMATION that is the property of
 * create3000.
 *
 * No permission is granted to copy, distribute, or create derivative works from
 * the contents of this software, in whole or in part, without the prior written
 * permission of create3000.
 *
 * NON-MILITARY USE ONLY
 *
 * All create3000 software are effectively free software with a non-military use
 * restriction. It is free. Well commented source is provided. You may reuse the
 * source in any way you please with the exception anything that uses it must be
 * marked to indicate is contains 'non-military use only' components.
 *
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * Copyright 2015, 2016 Holger Seelig <holger.seelig@yahoo.de>.
 *
 * This file is part of the X_ITE Project.
 *
 * X_ITE is free software: you can redistribute it and/or modify it under the
 * terms of the GNU General Public License version 3 only, as published by the
 * Free Software Foundation.
 *
 * X_ITE is distributed in the hope that it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
 * A PARTICULAR PURPOSE. See the GNU General Public License version 3 for more
 * details (a copy is included in the LICENSE file that accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version 3
 * along with X_ITE.  If not, see <http://www.gnu.org/licenses/gpl.html> for a
 * copy of the GPLv3 License.
 *
 * For Silvio, Joy and Adi.
 *
 ******************************************************************************/


define ([
   "x_ite/Fields",
   "x_ite/Components/Core/X3DNode",
   "x_ite/Base/X3DConstants",
],
function (Fields,
          X3DNode,
          X3DConstants)
{
"use strict";

   function X3DChildNode (executionContext)
   {
      if (this .getExecutionContext ())
         return;

      X3DNode .call (this, executionContext);

      this .addType (X3DConstants .X3DChildNode);

      this .addChildObjects ("isCameraObject",   new Fields .SFBool ());
      this .addChildObjects ("isPickableObject", new Fields .SFBool ());

      this ._isCameraObject   .setAccessType (X3DConstants .outputOnly);
      this ._isPickableObject .setAccessType (X3DConstants .outputOnly);
   }

   X3DChildNode .prototype = Object .assign (Object .create (X3DNode .prototype),
   {
      constructor: X3DChildNode,
      setCameraObject: function (value)
      {
         if (value !== this ._isCameraObject .getValue ())
            this ._isCameraObject = value;
      },
      getCameraObject: function ()
      {
         return this ._isCameraObject .getValue ();
      },
      setPickableObject: function (value)
      {
         if (value !== this ._isPickableObject .getValue ())
            this ._isPickableObject = value;
      },
      getPickableObject: function ()
      {
         return this ._isPickableObject .getValue ();
      },
   });

   return X3DChildNode;
});
